@@ -24,16 +24,15 @@ library(survival, quietly=TRUE)
 
 source("flipBox.R")
 
-if (!exists("runAppLocal",envir = as.environment("package:compareGroups"))) runAppLocal <- FALSE
-
-cat("runAppLocal: ",runAppLocal,"\n") 
+# if (!exists("runAppLocal",envir = as.environment("package:compareGroups"))) runAppLocal <- FALSE
+# cat("runAppLocal: ",runAppLocal,"\n") 
 
 
-if (!runAppLocal){
+#if (!runAppLocal){
   # insert entires logs
   sheet_id <- "https://docs.google.com/spreadsheets/d/11nVz8IjpLTwSJUDPK8uG5yG_rfNWc3nK6pE-TKx84BY/"
   gs4_auth(cache = ".secrets", email = "isubirana@datarus.eu", subject = "isubirana@datarus.eu",scope="spreadsheets", use_oob = TRUE)
-}
+#}
 
 
 data(regicor); data(SNPs)
